EncryptionHandler

Struct EncryptionHandler 

pub struct EncryptionHandler;
An EncryptionHandler is used to track and report on encrypted entries. Encrypted entries can trigger password prompts or hide payloads. Many extraction workflows choose to refuse them.