pub struct NamesHandler;Trait Implementations
Sourceimpl EntryAuditHandler for NamesHandler
An NamesHandler is used to track and report on suspicious (odd or OS-incompatible) names,
which often indicate obfuscation or extraction issues. For instance, the handler flags long
paths and very deep hierarchies, control characters in names, and certain reserved names.
impl EntryAuditHandler for NamesHandler
An NamesHandler is used to track and report on suspicious (odd or OS-incompatible) names,
which often indicate obfuscation or extraction issues. For instance, the handler flags long
paths and very deep hierarchies, control characters in names, and certain reserved names.