pub struct RecommendationsHandler;Expand description
A RecommendationsHandler is used to provide actionable guidance to configure safe extraction.
This is a report finalization handler that generates human-readable recommendations based
on aggregated report fields (e.g., depth, ratios, encryption, and such).