pub struct EntryView {Show 13 fields
pub compressed_size: u64,
pub depth_hint: usize,
pub enclosed_name: PathBuf,
pub encrypted: bool,
pub has_abs: bool,
pub has_parent_components: bool,
pub invalid_utf8: bool,
pub name_raw: Vec<u8>,
pub ratio: f64,
pub symlink: bool,
pub symlink_target: Option<String>,
pub uncompressed_size: u64,
pub unix_mode: Option<u32>,
}Expand description
A lightweight, precomputed view over a ZIP entry used by analysis handlers.
Fields
compressed_size: u64depth_hint: usizeenclosed_name: PathBufencrypted: boolhas_abs: boolhas_parent_components: boolinvalid_utf8: boolname_raw: Vec<u8>ratio: f64symlink: boolsymlink_target: Option<String>uncompressed_size: u64unix_mode: Option<u32>Implementations
Sourceimpl EntryView
impl EntryView
Sourcepub fn from_entry<R: Read + Seek>(entry: ZipFile<'_, R>) -> Self
pub fn from_entry<R: Read + Seek>(entry: ZipFile<'_, R>) -> Self
Processes a ZipFile and extracts relevant metadata and properties into an EntryView for
easier management and inspection. It performs operations like determining the entry name,
checking for invalid UTF-8 in the file name, computing compression ratios, and identifying
symbolic links.