pub struct PathHandler;Expand description
A PathHandler is used to track and report on suspicious paths, and signal safe extraction
policies. For instance, the handler detects absolute paths and parent components in entry names,
tracks the maximum directory depth hint across entries, and flags entries with invalid UTF-8
names.